/*
  Сервис интеграции ПП Парус 8 с WEB API
  Модели данных: описатели параметров функций обработчика очереди исходящих сообщений (класс OutQueue)
*/

//----------------------
// Подключение библиотек
//----------------------

const Schema = require("validate"); //Схемы валидации
const { outgoing } = require("./obj_config"); //Схемы валидации конфигурации сервера приложений
const { DBConnector } = require("../core/db_connector"); //Класс взаимодействия в БД
const { Logger } = require("../core/logger"); //Класс для протоколирования работы

//------------------
//  Интерфейс модуля
//------------------

//Схема валидации параметров конструктора
exports.OutQueue = new Schema({
    //Параметры обработки очереди исходящих сообщений
    outGoing: {
        schema: outgoing,
        required: true,
        message: {
            required: "Не указаны параметры обработки очереди исходящих сообщений (outGoing)"
        }
    },
    //Объект для взаимодействия с БД
    dbConn: {
        type: DBConnector,
        required: true,
        message: {
            type: "Объект для взаимодействия с БД (dbConn) имеет некорректный тип данных (ожидалось - DBConnector)",
            required: "Не указан объект для взаимодействия с БД (dbConn)"
        }
    },
    //Объект для протоколирования работы
    logger: {
        type: Logger,
        required: true,
        message: {
            type: "Объект для протоколирования работы (logger) имеет некорректный тип данных (ожидалось - Logger)",
            required: "Не указаны объект для протоколирования работы (logger)"
        }
    }
});
